@@ -1,20 +1,13 @@
-#!/usr/bin/env python
 """Fang and defang indicators of compromise."""
 
 import json
 import os
 import re
-import sys
 
 import click
 
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), ".")))
-import grammars
-
 FANG_DATA_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), "./fang.json"))
-DEFANG_DATA_PATH = os.path.abspath(
-    os.path.join(os.path.dirname(__file__), "./defang.json")
-)
+DEFANG_DATA_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), "./defang.json"))
 
 
 def _get_data_from_file(file_path):
@@ -36,18 +29,6 @@ def fang(text, debug=False):
         print('Starting text: {}'.format(fanged_text))
         print('-----')
 
-    fanged_text = grammars.dot_fanging_patterns.transformString(fanged_text)
-    fanged_text = grammars.at_fanging_patterns.transformString(fanged_text)
-    fanged_text = grammars.more_at_fanging_patterns.transformString(fanged_text)
-    fanged_text = grammars.colon_slash_slash_fanging_patterns.transformString(
-        fanged_text
-    )
-    fanged_text = grammars.colon_fanging_patterns.transformString(fanged_text)
-    fanged_text = grammars.odd_url_scheme_form.transformString(fanged_text)
-    fanged_text = grammars.http_fanging_patterns.transformString(fanged_text)
-    fanged_text = grammars.www_fanging_patterns.transformString(fanged_text)
-    fanged_text = grammars.comma_fanging_patterns.transformString(fanged_text)
-
     for mapping in fanging_mappings:
         if debug:
             print('Mapping: {}'.format(mapping))
@@ -60,9 +41,7 @@ def fang(text, debug=False):
         if mapping.get('case_sensitive'):
             fanged_text = re.sub(find_value, mapping['replace'], fanged_text)
         else:
-            fanged_text = re.sub(
-                find_value, mapping['replace'], fanged_text, flags=re.IGNORECASE
-            )
+            fanged_text = re.sub(find_value, mapping['replace'], fanged_text, flags=re.IGNORECASE)
 
         if debug:
             print('Text after mapping: {}'.format(fanged_text))
